@@ -218,7 +218,7 @@ G_STMT_START { \
 } G_STMT_END
 
 G_DEFINE_TYPE_WITH_CODE (GstTestClock, gst_test_clock,
-    GST_TYPE_CLOCK, _do_init);
+    GST_TYPE_CLOCK, G_ADD_PRIVATE (GstTestClock) _do_init);
 
 static GstObjectClass *parent_class = NULL;
 
@@ -261,8 +261,6 @@ gst_test_clock_class_init (GstTestClockClass * klass)
 
   parent_class = g_type_class_peek_parent (klass);
 
-  g_type_class_add_private (klass, sizeof (GstTestClockPrivate));
-
   gobject_class->constructed = GST_DEBUG_FUNCPTR (gst_test_clock_constructed);
   gobject_class->dispose = GST_DEBUG_FUNCPTR (gst_test_clock_dispose);
   gobject_class->finalize = GST_DEBUG_FUNCPTR (gst_test_clock_finalize);
@@ -304,8 +302,7 @@ gst_test_clock_init (GstTestClock * test_clock)
 {
   GstTestClockPrivate *priv;
 
-  test_clock->priv = G_TYPE_INSTANCE_GET_PRIVATE (test_clock,
-      GST_TYPE_TEST_CLOCK, GstTestClockPrivate);
+  test_clock->priv = gst_test_clock_get_instance_private (test_clock);
 
   priv = GST_TEST_CLOCK_GET_PRIVATE (test_clock);
 
@@ -691,8 +688,15 @@ gst_test_clock_new (void)
 GstClock *
 gst_test_clock_new_with_start_time (GstClockTime start_time)
 {
+  GstClock *clock;
+
   g_assert_cmpuint (start_time, !=, GST_CLOCK_TIME_NONE);
-  return g_object_new (GST_TYPE_TEST_CLOCK, "start-time", start_time, NULL);
+  clock = g_object_new (GST_TYPE_TEST_CLOCK, "start-time", start_time, NULL);
+
+  /* Clear floating flag */
+  gst_object_ref_sink (clock);
+
+  return clock;
 }
 
 /**
@@ -904,10 +908,6 @@ gst_test_clock_wait_for_next_pending_id (GstTestClock * test_clock,
  * Deprecated: use gst_test_clock_wait_for_multiple_pending_ids() instead.
  */
 #ifndef GST_REMOVE_DEPRECATED
-#ifdef GST_DISABLE_DEPRECATED
-void gst_test_clock_wait_for_pending_id_count (GstTestClock * test_clock,
-    guint count);
-#endif
 void
 gst_test_clock_wait_for_pending_id_count (GstTestClock * test_clock,
     guint count)
@@ -1034,6 +1034,55 @@ gst_test_clock_wait_for_multiple_pending_ids (GstTestClock * test_clock,
   GST_OBJECT_UNLOCK (test_clock);
 }
 
+/**
+ * gst_test_clock_timed_wait_for_multiple_pending_ids:
+ * @test_clock: #GstTestClock for which to await having enough pending clock
+ * @count: the number of pending clock notifications to wait for
+ * @timeout_ms: the timeout in milliseconds
+ * @pending_list: (out) (element-type Gst.ClockID) (transfer full) (allow-none): Address
+ *     of a #GList pointer variable to store the list of pending #GstClockIDs
+ *     that expired, or %NULL
+ *
+ * Blocks until at least @count clock notifications have been requested from
+ * @test_clock, or the timeout expires.
+ *
+ * MT safe.
+ *
+ * Returns: a @gboolean %TRUE if the waits have been registered, %FALSE if not.
+ * (Could be that it timed out waiting or that more waits than waits was found)
+ *
+ * Since: 1.16
+ */
+gboolean
+gst_test_clock_timed_wait_for_multiple_pending_ids (GstTestClock * test_clock,
+    guint count, guint timeout_ms, GList ** pending_list)
+{
+  GstTestClockPrivate *priv;
+  gint64 timeout = g_get_monotonic_time () +
+      timeout_ms * (G_USEC_PER_SEC / 1000);
+  gboolean ret;
+
+  g_return_val_if_fail (GST_IS_TEST_CLOCK (test_clock), FALSE);
+  priv = GST_TEST_CLOCK_GET_PRIVATE (test_clock);
+
+  GST_OBJECT_LOCK (test_clock);
+
+  while (g_list_length (priv->entry_contexts) < count &&
+      g_get_monotonic_time () < timeout) {
+    g_cond_wait_until (&priv->entry_added_cond,
+        GST_OBJECT_GET_LOCK (test_clock), timeout);
+  }
+
+  if (pending_list)
+    *pending_list = gst_test_clock_get_pending_id_list_unlocked (test_clock);
+
+  ret = (g_list_length (priv->entry_contexts) == count);
+
+  GST_OBJECT_UNLOCK (test_clock);
+
+  return ret;
+}
+
 /**
  * gst_test_clock_process_id_list:
  * @test_clock: #GstTestClock for which to process the pending IDs
